==> opennms-icmp-api-19.0.0-20161110.193025-288-sources.jar: org/opennms/netmgt/icmp/proxy/PingSweepRequestBuilder.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.icmp.proxy;

import java.net.InetAddress;
import java.util.List;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.TimeUnit;

import org.opennms.netmgt.model.discovery.IPPollRange;

public interface PingSweepRequestBuilder {
    

    PingSweepRequestBuilder withTimeout(long timeout, TimeUnit unit);

    PingSweepRequestBuilder withPacketSize(int packetSize);

    PingSweepRequestBuilder withRetries(int retries);

    PingSweepRequestBuilder withRange(InetAddress begin, InetAddress end);

    PingSweepRequestBuilder withLocation(String location);
    
    PingSweepRequestBuilder withForeignSource(String foreignSource);
    
    PingSweepRequestBuilder withIpPollRanges(List<IPPollRange> ranges);

    CompletableFuture<PingSweepSummary> execute();

}

==> opennms-icmp-api-19.0.0-20190511.184139-338-sources.jar: org/opennms/netmgt/icmp/proxy/PingSweepRequestBuilder.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.icmp.proxy;

import java.net.InetAddress;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.TimeUnit;

public interface PingSweepRequestBuilder {

    PingSweepRequestBuilder withLocation(String location);

    PingSweepRequestBuilder withPacketSize(int packetSize);

    PingSweepRequestBuilder withPacketsPerSecond(double packetsPerSecond);

    PingSweepRequestBuilder withRange(InetAddress begin, InetAddress end);

    PingSweepRequestBuilder withRange(InetAddress begin, InetAddress end, int retries, long timeout, TimeUnit timeoutUnit);

    CompletableFuture<PingSweepSummary> execute();

}
